@@ -1,12 +1,10 @@
 use Modern::Perl;
 package Renard::Incunabula::Common::Error;
 # ABSTRACT: Exceptions
-$Renard::Incunabula::Common::Error::VERSION = '0.003';
+$Renard::Incunabula::Common::Error::VERSION = '0.004';
 use custom::failures qw/
 	Programmer::Logic
 	IO::FileNotFound
-	User::InvalidPageNumber
-	ViewOptions::InvalidGridOptions
 	/;
 
 1;
@@ -23,7 +21,7 @@ Renard::Incunabula::Common::Error - Exceptions
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 EXTENDS
 
@@ -33,10 +31,6 @@ version 0.003
 
 =item * L<failure>
 
-=item * L<failure>
-
-=item * L<failure>
-
 =back
 
 =head1 AUTHOR
